@@ -13,6 +13,11 @@ ALPA_ISSUE_REPO_NAME = "issue-repo"
 ALPA_FEAT_BRANCH_PREFIX = "__feat_"
 ALPA_FEAT_BRANCH = ALPA_FEAT_BRANCH_PREFIX + "{pkgname}"
 
+GLOBAL_CFG_FILE = "/etc/vem.cfg"
+USER_CFG_FILE = "~/.config/vem.cfg"
+# order is important! user cfg overrides global cfg
+CONFIG_FILE_LOCATIONS = [USER_CFG_FILE, GLOBAL_CFG_FILE]
+
 
 class PackageRequest(str, Enum):
     TITLE = "[alpa] New request for package {package_name}"
